import pytest

import anysqlite


@pytest.mark.anyio
async def test_anysqlite():
    db = await anysqlite.connect(":memory:")

    try:
        cursor = await db.cursor()
        await cursor.execute("CREATE TABLE anysqlite_test(version TEXT)")
        await cursor.execute(
            "INSERT INTO anysqlite_test VALUES(?)", [anysqlite.__version__]
        )
        await cursor.execute("SELECT * FROM anysqlite_test")

        assert (anysqlite.__version__,) == await cursor.fetchone()
    finally:
        await db.close()



import typing as tp
import sqlite3

P = tp.ParamSpec("P")
T = tp.TypeVar("T")
RT = tp.TypeVar("RT")

def copy_sig(_: tp.Callable[P, T], returns: tp.Callable[..., RT]) -> tp.Callable[[tp.Callable[..., tp.Any]], tp.Callable[P, RT]]:

    def decorator(fnc: tp.Callable[..., tp.Any]) -> tp.Callable[P, RT]:

        def inner(*args, **kwargs):
            return fnc(*args, **kwargs)
    
        return inner

    return decorator

@copy_sig(sqlite3.connect, int.__new__)
async def connect(*args, **kwargs):
    ...


tp.reveal_type(connect)
a = connect()
tp.reveal_type(a)